<?php
#-------------------------------------------------------------------------
# Module: EventsManager
# Method: Upgrade
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
if (!isset($gCms)) exit;

$current_version = $oldversion;
switch($current_version)
{
  // we are now 0.1 and want to upgrade to latest
 case "0.1":
	$this->CreateEvent('EventsManagerEventAdded');
	$this->CreateEvent('EventsManagerEventEdited');
	$this->CreateEvent('EventsManagerEventDeleted');
	
	$this->CreateEvent('EventsManagerCategoryAdded');
	$this->CreateEvent('EventsManagerCategoryEdited');
	$this->CreateEvent('EventsManagerCategoryDeleted');
	
	$this->CreateEvent('EventsManagerRegistrationAdded');
	$this->CreateEvent('EventsManagerRegistrationEdited');
}

// put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded', $this->GetVersion()));
?>